// Copyrigth (C) 2012 - embedded.toolbox@gmail.com

// This program is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program.  If not, see <http://www.gnu.org/licenses/>.


#ifndef ARDRONE_DRIVER_H_
#define ARDRONE_DRIVER_H_

/**
 * Includes
 */
#include <stdio.h>
#include <stdlib.h>
#include <stdint.h>


/**
 * Enumerations
 */

/**
 *
 */
typedef enum { 
    RTM_FALSE = 0, 
    RTM_TRUE = 1
} rtm_boolean_t;

/**
 *
 */
typedef enum {
    RTM_NO_ERROR,
    RTM_NULL_POINTER,
    RTM_BAD_PARAMETER,
    RTM_ERROR_INTERNAL,
    RTM_ERROR_NO_MEMORY,
    RTM_ERROR_NOT_READY,
    RTM_ERROR_NO_DATA,
} rtm_error_t;


/**
 * Structures
 */


/**
 * Public functions
 */

/**
 *
 */
rtm_error_t ardrone_core_init (void);

/**
 *
 */
rtm_error_t ardrone_core_term (void);

/**
 *
 */
rtm_error_t ardrone_core_takeoff (void);

/**
 *
 */
rtm_error_t ardrone_core_land (void);

/**
 *
 */
rtm_error_t ardrone_core_emergency ();

/**
 *
 */
rtm_error_t ardrone_core_set_hover(void);

/**
 *
 */
rtm_error_t ardrone_core_set_progressive_cmd(void);

/**
 *
 */
rtm_error_t ardrone_core_set_zaxis_speed(double ardrone_zaxis_speed);

/**
 *
 */
rtm_error_t ardrone_core_set_yaw_speed(double ardrone_yaw_speed);

/**
 *
 */
rtm_error_t ardrone_core_set_phi_angle(double ardrone_phi_angle);

/**
 *
 */
rtm_error_t ardrone_core_set_theta_angle(double ardrone_phi_angle);

/**
 *
 */
rtm_error_t ardrone_core_get_speed(double * ardrone_vx_p,
                                   double * ardrone_vy_p,
                                   double * ardrone_vz_p);

/**
 *
 */
rtm_error_t ardrone_core_get_acceleration (double * ardrone_accx_p,
                                           double * ardrone_accy_p,
                                           double * ardrone_accz_p);

/**
 *
 */
rtm_error_t ardrone_core_get_angular_rates (double * ardrone_gyrox_p,
                                            double * ardrone_gyroy_p,
                                            double * ardrone_gyroz_p);

/**
 *
 */
rtm_error_t ardrone_core_get_magnetometer (double * ardrone_magx_p,
                                           double * ardrone_magy_p,
                                           double * ardrone_magz_p);

/**
 *
 */
rtm_error_t ardrone_core_get_yaw(double * ardrone_yaw_p);

/**
 *
 */
rtm_error_t ardrone_core_get_phi(double * ardrone_phi_p);

/**
 *
 */
rtm_error_t ardrone_core_get_theta(double * ardrone_theta_p);

/**
 *
 */
rtm_error_t ardrone_core_get_altitude(double * ardrone_altitude_p);

/**
 *
 */
rtm_error_t ardrone_core_get_image(double ** data_p, int * width, int * heigth, int number_of_colors);

/**
 *
 */
rtm_error_t ardrone_core_get_raw_image(uint8_t ** data_p, int * width, int * height);

/**
 *
 */
rtm_error_t ardrone_core_set_video_channel(int channel);

/**
 *
 */
rtm_error_t ardrone_core_get_pressure(double * ardrone_pressure_p);

/**
 *
 */
rtm_error_t ardrone_core_get_temperature(double * ardrone_temperature_p);

#endif // ARDRONE_DRIVER_H_

